==> 1.1.1.tar.gz: doc/GoogleApi.md <==
# forestvpn_api.api.GoogleApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**verifyGooglePlayPurchase**](GoogleApi.md#verifyGooglePlayPurchase) | **POST** /google/verify-purchase/ | Google play purchase verification service


# **verifyGooglePlayPurchase**
> verifyGooglePlayPurchase(request)

Google play purchase verification service

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = GoogleApi();
var request = GooglePlayPurchaseVerificationRequest(); // GooglePlayPurchaseVerificationRequest | 

try { 
    api_instance.verifyGooglePlayPurchase(request);
} catch (e) {
    print("Exception when calling GoogleApi->verifyGooglePlayPurchase: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**GooglePlayPurchaseVerificationRequest**](GooglePlayPurchaseVerificationRequest.md)|  | 

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> 1.2.4.tar.gz: doc/GoogleApi.md <==
# forestvpn_api.api.GoogleApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**verifyGooglePlayPurchase**](GoogleApi.md#verifygoogleplaypurchase) | **POST** /google/verify-purchase/ | Google play purchase verification service


# **verifyGooglePlayPurchase**
> verifyGooglePlayPurchase(request)

Google play purchase verification service

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = GoogleApi();
final request = GooglePlayPurchaseVerificationRequest(); // GooglePlayPurchaseVerificationRequest | 

try { 
    api_instance.verifyGooglePlayPurchase(request);
} catch (e) {
    print('Exception when calling GoogleApi->verifyGooglePlayPurchase: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**GooglePlayPurchaseVerificationRequest**](GooglePlayPurchaseVerificationRequest.md)|  | 

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
